emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[elpa] externals/trie d45e9d5 062/111: Added autoload cookies.


From: Stefan Monnier
Subject: [elpa] externals/trie d45e9d5 062/111: Added autoload cookies.
Date: Mon, 14 Dec 2020 11:35:21 -0500 (EST)

branch: externals/trie
commit d45e9d5062cc9984464829d71db1ee3c3074c342
Author: Toby S. Cubitt <toby-predictive@dr-qubit.org>
Commit: Toby S. Cubitt <toby-predictive@dr-qubit.org>

    Added autoload cookies.
---
 trie.el | 20 +++++++++++++++-----
 1 file changed, 15 insertions(+), 5 deletions(-)

diff --git a/trie.el b/trie.el
index 169201e..785ed4a 100644
--- a/trie.el
+++ b/trie.el
@@ -45,7 +45,7 @@
 ;; Lewenstein distance (though this last is not yet implemented in this
 ;; package - code contributions welcome!).
 ;;
 ;; You create a trie using `trie-create', create an association using
 ;; `trie-insert', retrieve an association using `trie-lookup', and map
 ;; over a trie using `trie-map', `trie-mapc', `trie-mapcar', or
 ;; `trie-mapf'. You can find completions of a prefix sequence using
@@ -489,7 +489,8 @@ type of sequence as SEQ."
 ;;; ================================================================
 ;;;                     Basic trie operations
 
-(defalias 'trie-create 'trie--create
+;;;###autoload
+(defalias 'make-trie 'trie--create
   "Return a new trie that uses comparison function COMPARISON-FUNCTION.
 
 A trie stores sequences (strings, vectors or lists) along with
@@ -499,12 +500,17 @@ if the first is strictly smaller than the second.
 
 The optional argument TYPE specifies the type of trie to
 create. However, the only one that is currently implemented is
-the default, so this argument is useless. (See also
-`trie-create-custom'.)")
+the default, so this argument is useless for now.
 
+(See also `make-trie-custom'.)")
 
 
-(defalias 'trie-create-custom 'trie--create-custom
+;;;###autoload
+(defalias 'trie-create 'make-trie)
+
+
+;;;###autoload
+(defalias 'make-trie-custom 'trie--create-custom
   "Return a new trie that uses comparison function COMPARISON-FUNCTION.
 
 A trie stores sequences (strings, vectors or lists) along with
@@ -611,6 +617,10 @@ functions must *never* bind any variables with names 
commencing
 \"--\".")
 
 
+;;;###autoload
+(defalias 'trie-create-custom 'make-trie-custom)
+
+
 
 (defalias 'trie-comparison-function 'trie--comparison-function
   "Return the comparison function for TRIE.")
@@ -45,7 +45,7 @@
 ;; package - code contributions welcome!).
 ;;
-;; You create a trie using `trie-create', create an association using
+;; You create a trie using `make-trie', create an association using
 ;; `trie-insert', retrieve an association using `trie-lookup', and map
 ;; over a trie using `trie-map', `trie-mapc', `trie-mapcar', or



reply via email to

[Prev in Thread] Current Thread [Next in Thread]